@@ -3,8 +3,9 @@
 Contains custom models
 """
 
+from .baselistmixin import BaseListMixin
+from .basemodelmixin import BaseModelMixin
 from .selectionmixin import SelectionMixin
-
 from .transposeproxymodel import TransposeProxyModel
 from .importlibdistributionmodel import ImportlibDistributionModel
 from .regexmatchesmodel import RegexMatchesModel
@@ -16,6 +17,8 @@ from .nestedmodel import NestedModel
 from .subsequencesortfilterproxymodel import SubsequenceSortFilterProxyModel
 
 __all__ = [
+    "BaseListMixin",
+    "BaseModelMixin",
     "SelectionMixin",
     "TransposeProxyModel",
     "ImportlibDistributionModel",
