@@ -1,21 +1,21 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
+from collections.abc import Iterable, Mapping
 import functools
 import pathlib
-from typing import Optional
+from typing import Any, Callable
 
 from prettyqt import custom_validators, custom_widgets, gui, widgets
+from prettyqt.utils import types
 
 
-class DataItem(object):
+class DataItem:
     def __init__(
         self,
-        label,
+        label: str,
         value=None,
-        optional=False,
-        include=True,
+        optional: str | None = None,
+        include: bool = True,
         enabled_on=None,
         disabled_on=None,
     ):
@@ -34,9 +34,7 @@ class DataItem(object):
         return self.value
 
     def set_pos(self, col=0, colspan=None):
-        """
-        Set data item's position on a GUI layout
-        """
+        """Set data item's position on a GUI layout."""
         self.label_col = col
         self.colspan = colspan
         return self
@@ -66,28 +64,15 @@ class Fixed(DataItem):
 
 
 class Float(DataItem):
-    """
-    Construct a float data item
-        * label [string]: name
-        * value [float]: default value (optional)
-        * min [float]: minimum value (optional)
-        * max [float]: maximum value (optional)
-        * slider [bool]: if True, shows a slider widget right after the line
-          edit widget (default is False)
-        * step [float]: step between tick values with a slider widget (optional)
-        * unit [string]: physical unit (optional)
-        * check [bool]: if False, value is not checked (optional, value=True)
-    """
-
     def __init__(
         self,
-        label,
-        value=None,
-        min_val=None,
-        max_val=None,
-        unit="",
-        step=0.1,
-        slider=False,
+        label: str,
+        value: float | None = None,
+        min_val: float | None = None,
+        max_val: float | None = None,
+        unit: str = "",
+        step: float = 0.1,
+        slider: bool = False,
         **kwargs,
     ):
         super().__init__(label, value=value, **kwargs)
@@ -95,7 +80,7 @@ class Float(DataItem):
         self.step = step
         self.unit = unit
 
-    def _create_widget(self):
+    def _create_widget(self) -> widgets.DoubleSpinBox:
         widget = widgets.DoubleSpinBox()
         widget.set_range(*self.range)
         widget.setSingleStep(self.step)
@@ -106,27 +91,15 @@ class Float(DataItem):
 
 
 class Int(DataItem):
-    """
-    Construct an integer data item
-        * label [string]: name
-        * value [int]: default value (optional)
-        * min [int]: minimum value (optional)
-        * max [int]: maximum value (optional)
-        * unit [string]: physical unit (optional)
-        * slider [bool]: if True, shows a slider widget right after the line
-          edit widget (default is False)
-        * check [bool]: if False, value is not checked (optional, value=True)
-    """
-
     def __init__(
         self,
-        label,
-        value=None,
-        min_val=0,
-        max_val=None,
-        unit="",
-        step=1,
-        slider=False,
+        label: str,
+        value: int | None = None,
+        min_val: int | None = 0,
+        max_val: int | None = None,
+        unit: str = "",
+        step: int = 1,
+        slider: bool = False,
         **kwargs,
     ):
         super().__init__(label, value=value, **kwargs)
@@ -135,13 +108,16 @@ class Int(DataItem):
         self.unit = unit
         self.slider = slider
 
-    def _create_widget(self):
-        if self.slider:
+    def _create_widget(self) -> custom_widgets.InputAndSlider | widgets.SpinBox:
+        min_val = self.range[0]
+        max_val = self.range[1]
+        if min_val is not None and max_val is not None:
             widget = custom_widgets.InputAndSlider()
+            widget.set_range(min_val, max_val)
         else:
             widget = widgets.SpinBox()
+            widget.set_range(min_val, max_val)
             widget.setSuffix(self.unit)
-        widget.set_range(*self.range)
         widget.set_step_size(self.step)
         if self.value is not None:
             widget.set_value(self.value)
@@ -149,54 +125,44 @@ class Int(DataItem):
 
 
 class Range(DataItem):
-    """
-    Construct a Range data item
-        * label [string]: name
-        * value [int]: default value (optional)
-        * min [int]: minimum value (optional)
-        * max [int]: maximum value (optional)
-        * unit [string]: physical unit (optional)
-        * slider [bool]: if True, shows a slider widget right after the line
-          edit widget (default is False)
-        * check [bool]: if False, value is not checked (optional, value=True)
-    """
-
-    def __init__(self, label, value=None, min_val=0, max_val=1, **kwargs):
+    def __init__(
+        self, label: str, value=None, min_val: int = 0, max_val: int = 1, **kwargs
+    ):
         super().__init__(label, value=value, **kwargs)
         self.range = (min_val, max_val)
         # self.step = step
         # self.unit = unit
 
-    def _create_widget(self):
-        widget = custom_widgets.SpanSliderWidget()
+    def _create_widget(self) -> custom_widgets.SpanSlider:
+        widget = custom_widgets.SpanSlider()
         # widget.setSuffix(self.unit)
         widget.set_range(*self.range)
-        widget.set_step_size(self.step)
+        # widget.set_step_size(self.step)
         if self.value is not None:
             widget.set_value(self.value)
         return widget
 
 
 class String(DataItem):
-    """
-    Construct a string data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * notempty [bool]: if True, empty string is not a valid value (opt.)
-    """
-
-    def __init__(self, label, value=None, notempty=False, regex=None, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        value: str | None = None,
+        notempty: bool = False,
+        regex: str | None = None,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.notempty = notempty
         self.regex = regex
 
-    def _create_widget(self):
+    def _create_widget(self) -> widgets.LineEdit:
         widget = widgets.LineEdit()
         if self.notempty:
             val = custom_validators.NotEmptyValidator()
             widget.set_validator(val)
         if self.regex is not None:
-            val = gui.RegExpValidator()
+            val = gui.RegularExpressionValidator()
             val.set_regex(self.regex)
             widget.set_validator(val)
         if self.value is not None:
@@ -204,19 +170,32 @@ class String(DataItem):
         return widget
 
 
-class Code(DataItem):
-    """
-    Construct a code data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * language [string]: language for syntax highlighting
-    """
+class RegexPattern(DataItem):
+    def __init__(
+        self, label: str, value: str | None = None, notempty: bool = False, **kwargs
+    ):
+        super().__init__(label, value=value, **kwargs)
+        self.notempty = notempty
 
-    def __init__(self, label, value=None, language="python", **kwargs):
+    def _create_widget(self) -> custom_widgets.SingleLineTextEdit:
+        widget = custom_widgets.SingleLineTextEdit()
+        if self.notempty:
+            val = custom_validators.NotEmptyValidator()
+            widget.set_validator(val)
+        widget.set_syntaxhighlighter("regex")
+        if self.value is not None:
+            widget.set_value(self.value)
+        return widget
+
+
+class Code(DataItem):
+    def __init__(
+        self, label: str, value: str | None = None, language: str = "python", **kwargs
+    ):
         super().__init__(label, value=value, **kwargs)
         self.language = language
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.CodeEditor:
         widget = custom_widgets.CodeEditor()
         if self.value is not None:
             widget.set_value(self.value)
@@ -224,17 +203,10 @@ class Code(DataItem):
 
 
 class Regex(DataItem):
-    """
-    Construct a code data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * language [string]: language for syntax highlighting
-    """
-
     def __init__(
         self,
         label: str,
-        value=None,
+        value: str | None = None,
         show_flags: bool = True,
         show_error: bool = False,
         **kwargs,
@@ -243,7 +215,7 @@ class Regex(DataItem):
         self.show_flags = show_flags
         self.show_error = show_error
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.RegexInput:
         widget = custom_widgets.RegexInput(
             show_flags=self.show_flags, show_error=self.show_error
         )
@@ -253,18 +225,17 @@ class Regex(DataItem):
 
 
 class IntList(DataItem):
-    """
-    Construct an IntList data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * notempty [bool]: if True, empty string is not a valid value (opt.)
-    """
-
-    def __init__(self, label, value=None, allow_single=False, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        value: list[int] | None = None,
+        allow_single: bool = False,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.allow_single = allow_single
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.ListInput:
         widget = custom_widgets.ListInput(allow_single=self.allow_single)
         if self.value is not None:
             widget.set_value(self.value)
@@ -272,18 +243,17 @@ class IntList(DataItem):
 
 
 class FloatList(DataItem):
-    """
-    Construct an FloatList data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * notempty [bool]: if True, empty string is not a valid value (opt.)
-    """
-
-    def __init__(self, label, value=None, allow_single=False, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        value: list[float] | None = None,
+        allow_single: bool = False,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.allow_single = allow_single
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.ListInput:
         widget = custom_widgets.ListInput(allow_single=self.allow_single, typ=float)
         if self.value is not None:
             widget.set_value(self.value)
@@ -291,42 +261,31 @@ class FloatList(DataItem):
 
 
 class Bool(DataItem):
-    """
-    Construct a boolean data item
-        * text [string]: form's field name (optional)
-        * label [string]: name
-        * value [string]: default value (optional)
-        * check [bool]: if False, value is not checked (optional, value=True)
-    """
-
-    def __init__(self, label, value=False, true_value=True, false_value=False, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        value: bool = False,
+        true_value: Any = True,
+        false_value: Any = False,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.true_value = true_value
         self.false_value = false_value
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.MappedCheckBox:
         widget = custom_widgets.MappedCheckBox(
             true_value=self.true_value, false_value=self.false_value
         )
-        if self.value is not None:
-            widget.set_value(self.value)
+        widget.set_value(self.value)
         return widget
 
 
 class Color(DataItem):
-    """
-    Construct a color data item
-        * label [string]: name
-        * value [string]: default value (optional)
-        * check [bool]: if False, value is not checked (optional, value=True)
-
-    Color values are encoded as hexadecimal strings or Qt color names
-    """
-
-    def __init__(self, label, value=None, **kwargs):
+    def __init__(self, label: str, value=None, **kwargs):
         super().__init__(label, value=value, **kwargs)
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.ColorChooserButton:
         widget = custom_widgets.ColorChooserButton()
         if self.value is not None:
             widget.set_value(self.value)
@@ -334,75 +293,91 @@ class Color(DataItem):
 
 
 class Enum(DataItem):
-    """
-    Construct a data item for a list of choices.
-        * label [string]: name
-        * choices [list, tuple or function]: string list or (key, label) list
-          function of two arguments (item, value) returning a list of tuples
-          (key, label, image) where image is an icon path, a QIcon instance
-          or a function of one argument (key) returning a QIcon instance
-        * value [-]: default label or default key (optional)
-        * check [bool]: if False, value is not checked (optional, value=True)
-        * radio [bool]: if True, shows radio buttons instead of a combo box
-          (default is False)
-    """
-
-    def __init__(self, label, choices, value=None, radio=False, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        choices: Iterable | Mapping,
+        value: Any = None,
+        radio: bool = False,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.radio = radio
         self.choices = choices
 
-    def _create_widget(self):
+    def _create_widget(
+        self,
+    ) -> custom_widgets.ColorChooserButton | widgets.ComboBox:
         if self.radio:
             widget = custom_widgets.SelectionWidget(layout="vertical")
         else:
             widget = widgets.ComboBox()
-        for item in self.choices:
-            if isinstance(item, tuple):
-                if len(item) == 2:
-                    widget.add(item[1], item[0])
-                elif len(item) == 3:
-                    widget.add(item[1], item[0], item[2])
-            else:
-                widget.add(item)
+        if isinstance(self.choices, Mapping):
+            widget.add_items(self.choices)
+        else:
+            for item in self.choices:
+                if isinstance(item, tuple):
+                    if len(item) == 2:
+                        widget.add(item[1], item[0])
+                    elif len(item) == 3:
+                        widget.add(item[1], item[0], item[2])
+                else:
+                    widget.add(item)
         if self.value is not None:
             widget.set_value(self.value)
         return widget
 
 
 class MultipleChoice(DataItem):
-    def __init__(self, label, choices, value=None, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        choices: Iterable | Mapping,
+        value: list | None = None,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.choices = choices
 
-    def _create_widget(self):
+    def _create_widget(self) -> widgets.ListWidget:
         widget = widgets.ListWidget()
         widget.set_selection_mode("multi")
-        for item in self.choices:
-            if isinstance(item, tuple):
-                if len(item) == 2:
-                    widget.add(item[1], item[0])
-                elif len(item) == 3:
-                    widget.add(item[1], item[0], item[2])
-            else:
-                widget.add(item)
+        if isinstance(self.choices, Mapping):
+            widget.add_items(self.choices)
+        else:
+            for item in self.choices:
+                if isinstance(item, tuple):
+                    if len(item) == 2:
+                        widget.add(item[1], item[0])
+                    elif len(item) == 3:
+                        widget.add(item[1], item[0], item[2])
+                else:
+                    widget.add(item)
         if self.value is not None:
             widget.set_value(self.value)
         return widget
 
 
 class File(DataItem):
-    def __init__(self, label, formats="*", value=None, save=True, root=None, **kwargs):
+    def __init__(
+        self,
+        label: str,
+        formats: str = "*",
+        value: None | str | pathlib.Path = None,
+        save: bool = True,
+        root: None | str | pathlib.Path = None,
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.formats = formats.lstrip(".")
         self.root = root
         self.save = save
 
-    def _create_widget(self):
-        file_mode = "any_file" if self.save else "existing_file"
-        mode = "save" if self.save else "open"
+    def _create_widget(self) -> custom_widgets.FileChooserButton:
         widget = custom_widgets.FileChooserButton(
-            file_mode=file_mode, mode=mode, root=self.root
+            file_mode="any_file" if self.save else "existing_file",
+            mode="save" if self.save else "open",
+            root=self.root,
         )
         if self.value is not None:
             widget.set_value(self.value)
@@ -410,12 +385,19 @@ class File(DataItem):
 
 
 class Folder(DataItem):
-    def __init__(self, label, value=None, root=None, mode="open", **kwargs):
+    def __init__(
+        self,
+        label: str,
+        value: None | str | pathlib.Path = None,
+        root: None | str | pathlib.Path = None,
+        mode: widgets.filedialog.AcceptModeStr = "open",
+        **kwargs,
+    ):
         super().__init__(label, value=value, **kwargs)
         self.mode = mode
         self.root = root
 
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.FileChooserButton:
         widget = custom_widgets.FileChooserButton(
             file_mode="directory", mode=self.mode, root=self.root
         )
@@ -425,7 +407,7 @@ class Folder(DataItem):
 
 
 class StringOrNumber(DataItem):
-    def _create_widget(self):
+    def _create_widget(self) -> custom_widgets.StringOrNumberWidget:
         widget = custom_widgets.StringOrNumberWidget(self.label)
         if self.value is not None:
             widget.set_value(self.value)
@@ -433,43 +415,21 @@ class StringOrNumber(DataItem):
 
 
 class Button(DataItem):
-    """
-    Construct a simple button that calls a method when hit
-        * label [string]: text shown on the button
-        * callback [function]: function with four params (dataset, item, value, parent)
-            - dataset [DataSet]: instance of the parent dataset
-            - item [DataItem]: instance of Button (i.e. self)
-            - value [unspecified]: value of Button (default Button
-              value or last value returned by the callback)
-            - parent [QObject]: button's parent widget
-        * icon [QIcon or string]: icon show on the button (optional)
-        * check [bool]: if False, value is not checked (optional, value=True)
-    """
-
-    def __init__(self, label, callback, icon=None, value=None):
-        super().__init__("", value=value, include=False)
+    def __init__(self, label: str, callback: Callable, icon: types.IconType = None):
+        super().__init__("", value=None, include=False)
         self.button_label = label
         self.icon = icon
         self.callback = callback
 
-    def _create_widget(self):
+    def _create_widget(self) -> widgets.PushButton:
         widget = widgets.PushButton(self.button_label)
         widget.set_icon(self.icon)
-        if self.value is not None:
-            widget.set_value(self.value)
         callback = functools.partial(self.callback, parent=widget.window())
         widget.clicked.connect(callback)
         return widget
 
 
 class DataSetMeta(type):
-    """
-    DataSet metaclass
-
-    Create class attribute `_items`: list of the DataSet class attributes,
-    created in the same order as these attributes were written
-    """
-
     def __new__(mcs, name, bases, dct):
         filtered = [b for b in bases if getattr(b, "__metaclass__", None) is DataSetMeta]
         items = {item._name: item for b in filtered for item in b._items}
@@ -482,16 +442,17 @@ class DataSetMeta(type):
         return type.__new__(mcs, name, bases, dct)
 
 
-class DataSet(object, metaclass=DataSetMeta):
-    def __init__(self, title=None, comment=None, icon=""):
+class DataSet(metaclass=DataSetMeta):
+    _items: dict[str, DataItem]
+
+    def __init__(self, title: str = "", comment: str | None = None, icon=""):
         # self.widget = custom_widgets.SettingsWidget()
         self.dialog_title = title
         self.dialog_comment = comment
         self.dialog_icon = icon
-        self.ok_btn = None
 
     def create_dialog(self):
-        dialog = widgets.BaseDialog()
+        dialog = widgets.Dialog()
         dialog.set_modality("application")
         dialog.setMinimumWidth(400)
         dialog.set_title(self.dialog_title)
@@ -501,7 +462,7 @@ class DataSet(object, metaclass=DataSetMeta):
         dialog.box.set_margin(20)
 
         button_box = widgets.DialogButtonBox()
-        self.ok_btn = button_box.add_default_button("ok", callback=dialog.accept)
+        ok_btn = button_box.add_default_button("ok", callback=dialog.accept)
         button_box.add_default_button("cancel", callback=dialog.reject)
         widget_dict = {k: v.create_widget() for k, v in self._items.items()}
         widget_dict = {k: v for k, v in widget_dict.items() if v is not None}
@@ -511,7 +472,7 @@ class DataSet(object, metaclass=DataSetMeta):
                 i.is_valid() if hasattr(i, "is_valid") else True
                 for i in widget_dict.values()
             )
-            self.ok_btn.setEnabled(is_valid)
+            ok_btn.setEnabled(is_valid)
 
         for i, (k, item) in enumerate(self._items.items()):
             if k not in widget_dict:
@@ -535,17 +496,22 @@ class DataSet(object, metaclass=DataSetMeta):
         on_update()
         return dialog
 
-    def edit(self, preset: Optional[dict] = None) -> bool:
+    def edit(self, preset: dict | None = None) -> bool:
         dialog = self.create_dialog()
         if preset:
             for item in dialog.layout():
-                if item.id in preset and preset[item.id] is not None:
-                    item.set_value(preset[item.id])
+                item_id = item.get_id()
+                if item_id in preset and preset[item_id] is not None:
+                    item.set_value(preset[item_id])
 
         if not dialog.show_blocking():
             return False
-        new_values = {item.id: item.get_value() for item in dialog.layout() if item.id}
-        enabled = {item.id: item.isEnabled() for item in dialog.layout() if item.id}
+        new_values = {
+            item.get_id(): item.get_value() for item in dialog.layout() if item.has_id()
+        }
+        enabled = {
+            item.get_id(): item.isEnabled() for item in dialog.layout() if item.has_id()
+        }
         # new_values = {a: (str(b) if isinstance(b, pathlib.Path) else b)
         #               for a, b in dct.items()}
         for k, item in self._items.items():
@@ -572,11 +538,13 @@ if __name__ == "__main__":
         enum = Enum(label="Enum", choices=["A", "B"], disabled_on="boolitem")
         floatitem = Float(label="Float", enabled_on="boolitem")
         fileitem = File(label="File", optional="Activate")
+        rangeitem = Range(label="Range", max_val=10)
         folderitem = Folder(label="Folder", include=False)
         buttonitem = Button(label="Folder", icon="mdi.folder", callback=print)
         stringornumber = StringOrNumber(label="StringOrNumber", value=2.4)
         code = Code(label="Test", value="class Test")
-        # code = Regex(label="Test", value="[", show_error=False)
+        regexpattern = RegexPattern("RegexPattern")
+        regex = Regex(label="Test", value="[", show_error=False)
 
     # class Test2(Test):
     #     boolitem = None
