@@ -1,19 +1,23 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 class OptionalWidget(widgets.GroupBox):
-    def __init__(self, widget, title="", parent=None):
+    def __init__(
+        self,
+        widget: QtWidgets.QWidget,
+        title: str = "",
+        parent: QtWidgets.QWidget | None = None,
+    ):
         super().__init__(checkable=True, title=title)
         self.set_layout("vertical")
         self.box.add(widget)
         self.widget = widget
         self.toggled.connect(self.widget.setEnabled)
 
-    def __getattr__(self, value):
+    def __getattr__(self, value: str):
         return self.widget.__getattribute__(value)
 
     @property
@@ -35,5 +39,5 @@ if __name__ == "__main__":
     img = widgets.RadioButton("test")
     widget = OptionalWidget(img, "Test")
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.enabled)
