@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 from prettyqt import core, widgets
+from prettyqt.qt import QtWidgets
 
 
 class StringOrNumberWidget(widgets.GroupBox):
 
     value_changed = core.Signal(object)
 
-    def __init__(self, title="", parent=None):
+    def __init__(self, title: str = "", parent: QtWidgets.QWidget | None = None):
         super().__init__(checkable=False, title=title)
         self.set_layout("vertical")
         self.rb_lineedit = widgets.RadioButton("String")
@@ -36,14 +35,14 @@ class StringOrNumberWidget(widgets.GroupBox):
         value = self.get_value()
         self.value_changed.emit(value)
 
-    def get_value(self):
+    def get_value(self) -> float | str:
         if self.rb_spinbox.isChecked():
             val = self.spinbox.get_value()
             return int(val) if val.is_integer() else val
         else:
             return self.lineedit.get_value()
 
-    def set_value(self, value):
+    def set_value(self, value: float | str):
         if isinstance(value, str):
             self.rb_lineedit.setChecked(True)
             self.lineedit.set_value(value)
@@ -59,5 +58,5 @@ if __name__ == "__main__":
     widget = StringOrNumberWidget("Test")
     widget.value_changed.connect(print)
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.enabled)
