@@ -1,12 +1,10 @@
 """Provides QtWidgets classes and functions."""
 
-from prettyqt.qt import PYQT5, PYQT6, PYSIDE2, PYSIDE6, PythonQtError
+from prettyqt.qt import PYQT5, PYQT6, PYSIDE6, PythonQtError
 
 
 if PYQT5:
     from PyQt5.QtWidgets import *
-elif PYSIDE2:
-    from PySide2.QtWidgets import *
 elif PYQT6:
     from PyQt6.QtWidgets import *  # type: ignore
     from PyQt6.QtOpenGLWidgets import QOpenGLWidget  # type: ignore
