@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
-
-from qtpy import QtWidgets
+from __future__ import annotations
 
 from prettyqt import core
+from prettyqt.qt import QtWidgets
 
 
 QtWidgets.QAbstractItemDelegate.__bases__ = (core.Object,)
