@@ -59,7 +59,6 @@ class ComboBox(QtWidgets.QComboBox):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.currentIndexChanged.connect(self.index_changed)
-        self.setCompleter(widgets.Completer(self))
 
     def serialize_fields(self):
         items = [
@@ -78,10 +77,9 @@ class ComboBox(QtWidgets.QComboBox):
             size_adjust_policy=self.get_size_adjust_policy(),
             duplicates_enabled=self.duplicatesEnabled(),
             min_contents_length=self.minimumContentsLength(),
+            placeholder_text=self.placeholderText(),
             items=items,
         )
-        if core.VersionNumber.get_qt_version() >= (5, 15, 0):
-            dct["placeholder_text"] = self.placeholderText()
         return dct
 
     def __setstate__(self, state):
@@ -134,6 +132,11 @@ class ComboBox(QtWidgets.QComboBox):
             return None
         return gui.Icon(icon)
 
+    def set_editable(self, editable: bool):
+        self.setEditable(editable)
+        if self.completer() is None and editable:
+            self.setCompleter(widgets.Completer(self))
+
     def set_insert_policy(self, policy: InsertPolicyStr):
         """Set insert policy.
 
