@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
-
-from qtpy import QtWidgets
+from __future__ import annotations
 
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QErrorMessage.__bases__ = (widgets.BaseDialog,)
+QtWidgets.QErrorMessage.__bases__ = (widgets.Dialog,)
 
 
 class ErrorMessage(QtWidgets.QErrorMessage):
@@ -20,4 +16,4 @@ if __name__ == "__main__":
     widget = ErrorMessage()
     widget.set_icon("mdi.timer")
     widget.show()
-    app.exec_()
+    app.main_loop()
