@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Any, Callable
 
 from prettyqt import constants, core, iconprovider, widgets
-from prettyqt.qt import QtCore, QtWidgets
+from prettyqt.qt import QtWidgets
 from prettyqt.utils import InvalidParamError, helpers, types
 
 
